ios: Correct typo in client API StartProcessingPendingReports.

Change-Id: I02fb7c633a0e6d172c7c54abd1287282798ea3c0
Reviewed-on: https://chromium-review.googlesource.com/c/crashpad/crashpad/+/3031701
Reviewed-by: Mark Mentovai <mark@chromium.org>
Commit-Queue: Justin Cohen <justincohen@chromium.org>
GitOrigin-RevId: b8a16857735ba8e6464696362625bf54938417d7
diff --git a/client/crashpad_client_ios.cc b/client/crashpad_client_ios.cc
index 5c1f1ee..a8ef224 100644
--- a/client/crashpad_client_ios.cc
+++ b/client/crashpad_client_ios.cc
@@ -233,7 +233,7 @@
 }
 
 // static
-void CrashpadClient::StartProcesingPendingReports() {
+void CrashpadClient::StartProcessingPendingReports() {
   // TODO(justincohen): Start the CrashReportUploadThread.
 }
 
diff --git a/doc/ios_overview_design.md b/doc/ios_overview_design.md
index 943d7a5..1c4d6dd 100644
--- a/doc/ios_overview_design.md
+++ b/doc/ios_overview_design.md
@@ -96,7 +96,7 @@
 stability concerns. In this case, intermediate dumps are automatically
 converted to minidumps and immediately eligible for uploading.
 
-### `StartProcesingPendingReports`
+### `StartProcessingPendingReports`
 For similar reasons, applications may choose the correct time to begin uploading
 pending reports, such as when ideal network conditions exist. By default,
 clients start with uploading disabled. Applications should call this API when
diff --git a/client/crashpad_client.h b/client/crashpad_client.h
index 10ad404..eea953d 100644
--- a/client/crashpad_client.h
+++ b/client/crashpad_client.h
@@ -506,11 +506,11 @@
   //! on another thread. This method does not block.
   //!
   //! A handler must have already been installed before calling this method.
-  static void StartProcesingPendingReports();
+  static void StartProcessingPendingReports();
 
   //! \brief Requests that the handler capture an intermediate dump even though
   //!     there hasn't been a crash. The intermediate dump will be converted
   //!     to a mindump immediately. If StartProcesingPendingReports() has been
   //!     called, this will also trigger an upload.
   //!
   //! For internal use only. Clients should use CRASHPAD_SIMULATE_CRASH().
@@ -506,11 +506,11 @@
   //! \brief Requests that the handler capture an intermediate dump even though
   //!     there hasn't been a crash. The intermediate dump will be converted
-  //!     to a mindump immediately. If StartProcesingPendingReports() has been
+  //!     to a mindump immediately. If StartProcessingPendingReports() has been
   //!     called, this will also trigger an upload.
   //!